@@ -23,6 +23,9 @@
 #include <algorithm>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Box_DB_Table_Relationships::Box_DB_Table_Relationships()
 {
   init();
@@ -43,6 +46,7 @@ void Box_DB_Table_Relationships::init()
 
   m_colTitle = m_AddDel.add_column(_("Title"));
 
+  //Translators: FROM as in SQL's FROM
   m_colFromField = m_AddDel.add_column(_("From Field"), AddDelColumnInfo::STYLE_Choices);
   m_colToTable = m_AddDel.add_column(_("Table"), AddDelColumnInfo::STYLE_Choices);
   m_colToField = m_AddDel.add_column(_("To Field"), AddDelColumnInfo::STYLE_Choices);
@@ -120,8 +124,6 @@ bool Box_DB_Table_Relationships::fill_from_database()
     }
   }
 
-  fill_end();
-
   return result;
 }
 
@@ -185,7 +187,7 @@ void Box_DB_Table_Relationships::on_adddel_user_added(const Gtk::TreeModel::iter
     Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
     if(title.empty())
     {
-      title = Base_DB::util_title_from_string(new_name);
+      title = Utils::title_from_string(new_name);
       m_AddDel.set_value(row, m_colTitle, title);
     }
   }
@@ -204,7 +206,7 @@ void Box_DB_Table_Relationships::on_adddel_user_changed(const Gtk::TreeModel::it
     Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
     if(title.empty())
     {
-      title = Base_DB::util_title_from_string(new_name);
+      title = Utils::title_from_string(new_name);
       m_AddDel.set_value(row, m_colTitle, title);
     }
   }
@@ -281,3 +283,5 @@ void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::Tree
 
   set_modified();
 }
+
+} //namespace Glom
